<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Models\Service;
use Illuminate\Http\Request;

class ServicesController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        $rows = Service::all();
        return view('admin.services.index', compact('rows'));
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        return view('admin.services.create');
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param \Illuminate\Http\Request $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        $this->validate($request, [
            'name_en' => 'required',
            'name_ar' => 'required',
            'price' => 'required',
            'image' => 'required|image',
            'duration' => 'required'
        ]);
        $service = new Service();
        $service['name->ar'] = $request['name_ar'];
        $service['name->en'] = $request['name_en'];
        $service['price'] = $request['price'];
        $service['duration'] = $request['duration'];
        if ($request->hasFile('image')) $service->setImageAttribute();
        $service->save();
        toast('تمت العمليه بنجاح', 'success');
        return redirect()->route('services.index');
    }

    /**
     * Display the specified resource.
     *
     * @param int $id
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param int $id
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        $row = Service::find($id);
        return view('admin.services.edit', compact('row'));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param \Illuminate\Http\Request $request
     * @param int $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {
        $this->validate($request, [
            'name_en' => 'required',
            'name_ar' => 'required',
            'price' => 'required',
            'image' => 'required|image',
            'duration' => 'required'
        ]);
        $service = Service::find($id);
        $service['name->ar'] = $request['name_ar'];
        $service['name->en'] = $request['name_en'];
        $service['price'] = $request['price'];
        $service['duration'] = $request['duration'];
        if ($request->hasFile('image')) $service->setImageAttribute();
        $service->update();
        toast('تمت العمليه بنجاح', 'success');
        return redirect()->route('services.index');
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param int $id
     * @return \Illuminate\Http\Response
     */
    public function destroy($id)
    {
        Service::destroy($id);
        toast('تمت العمليه بنجاح', 'success');
        return back();
    }
}
