<?php

namespace App\Http\Controllers\Api;

use App\Http\Controllers\Controller;
use App\Http\Resources\OffersResource;
use App\Models\Contact;
use App\Models\Offer;
use App\Models\Rate;
use App\Models\Setting;
use Carbon\Carbon;
use DateTime;
use Illuminate\Http\Request;
use JWTAuth;

class DataController extends Controller
{
    public function rate(Request $request)
    {
        $lang = \request()->header('Accept-Language', 'ar');
        \App::setLocale($lang);
        if (!$user = JWTAuth::parseToken()->authenticate()) {
            return response()->json(['value' => false, 'msg' => \Lang::get('wrong token'), 'code' => 401]);
        }
        $validator = \Validator::make($request->all(), [
            'barber_id' => 'required',
            'rate' => 'required',
            'body' => 'required'
        ]);
        if ($validator->passes()) {
            Rate::create([
                'user_id' => $user->id,
                'rated_id' => $request['barber_id'],
                'rate' => $request['rate'],
                'body' => $request['body'],
                'type' => 'client_barber'
            ]);
            return response()->json(['value' => true, 'data' => \Lang::get('data.rated'), 'code' => 200]);
        } else {
            return response()->json(['value' => false, 'msg' => $validator->errors()->first(), 'code' => 422]);
        }
    }

    public function rate_client(Request $request)
    {
        $lang = \request()->header('Accept-Language', 'ar');
        \App::setLocale($lang);
        if (!$user = JWTAuth::parseToken()->authenticate()) {
            return response()->json(['value' => false, 'msg' => \Lang::get('wrong token'), 'code' => 401]);
        }
        $validator = \Validator::make($request->all(), [
            'client_id' => 'required',
            'rate' => 'required',
            'body' => 'required'
        ]);
        if ($validator->passes()) {
            Rate::create([
                'user_id' => $user->id,
                'rated_id' => $request['client_id'],
                'rate' => $request['rate'],
                'body' => $request['body'],
                'type' => 'barber_client'
            ]);
            return response()->json(['value' => true, 'data' => \Lang::get('data.rated'), 'code' => 200]);
        } else {
            return response()->json(['value' => false, 'msg' => $validator->errors()->first(), 'code' => 422]);
        }
    }

    public function settings()
    {
        $lang = \request()->header('Accept-Language', 'ar');
        \Lang::setLocale($lang);

        $setting = Setting::first();
        $timeA = $setting->open_from;
        $timeB = $setting->open_to;

        $input = new DateTime(Carbon::now());
        $begin = new DateTime($timeA);
        $end = new DateTime($timeB);
        if ($input >= $begin && $input <= $end) {
            $open_status = 'open';
        } else {
            $open_status = 'closed';
        }
        $data['about'] = $setting->about[$lang];
        $data['open_status'] = $open_status;
        $data['discount_fee'] = $setting->discount_fee ? $setting->discount_fee : '';
        $data['ios_link'] = $setting->ios_link ? $setting->ios_link : '';
        $data['android_link'] = $setting->android_link ? $setting->android_link :'';
        return response()->json(['value' => true, 'data' => $data, 'code' => 200]);
    }

    public function contacts(Request $request)
    {
        $lang = \request()->header('Accept-Language', 'ar');
        \App::setLocale($lang);
        if (!$user = JWTAuth::parseToken()->authenticate()) {
            return response()->json(['value' => false, 'msg' => \Lang::get('wrong token'), 'code' => 401]);
        }
        $validator = \Validator::make($request->all(), [
            'message' => 'required'
        ]);
        if ($validator->passes()) {
            Contact::create([
                'user_id' => $user->id,
                'message' => $request['message']
            ]);
            return response()->json(['value' => true, 'data' => \Lang::get('data.sent'), 'code' => 200]);
        } else {
            return response()->json(['value' => false, 'msg' => $validator->errors()->first(), 'code' => 422]);
        }
    }

    public function offers(Request $request)
    {
        $lang = $request->header('Accept-Language', 'ar');
        \App::setLocale($lang);
//        if ($request->header('Authorization')){
//            if (!$user = JWTAuth::parseToken()->authenticate()) {
//                return response()->json(['value' => false, 'msg' => \Lang::get('wrong token'), 'code' => 401]);
//            }
//
//            $my_offers = Offer::where('user_id',$user->id)->pluck('id');
//
//
//        }
//
//        $all_offers = Offer::where('user_id',null)->pluck('id');
//
//        $merged_offers = $all_offers->merge($my_offers);


        $rows = Offer::where('user_id',null)->where('available','true')->orderByDesc('id')->paginate(20);
        return OffersResource::collection($rows)->additional(['value' => true, 'code' => 200]);

    }

    public function my_offers()
    {
        $lang = \request()->header('Accept-Language', 'ar');
        \App::setLocale($lang);
        if (!$user = JWTAuth::parseToken()->authenticate()) {
            return response()->json(['value' => false, 'msg' => \Lang::get('wrong token'), 'code' => 401]);
        }
        $rows = Offer::where('user_id', $user->id)->where('available','true')->orderByDesc('id')->paginate(20);
        return OffersResource::collection($rows)->additional(['value' => true, 'code' => 200]);

    }

    public function create_offer()
    {
        $lang = \request()->header('Accept-Language', 'ar');
        \App::setLocale($lang);
        if (!$user = JWTAuth::parseToken()->authenticate()) {
            return response()->json(['value' => false, 'msg' => \Lang::get('wrong token'), 'code' => 401]);
        }
        $offer = new Offer();
        $offer['user_id'] = $user->id;
        $code = rand(1111,9999);
        $offer['body->ar'] = " لديك خصم جديد وكود الخصم هو $code  ";
        $offer['body->en'] = " You have a new discount and the code is $code  ";
        $offer['code'] = $code;
        $offer['discount'] = 10;
        $offer->save();
        $rows = Offer::where('user_id', $user->id)->orderByDesc('id')->paginate(20);
        return OffersResource::collection($rows)->additional(['value' => true, 'code' => 200]);

    }
}
