<?php

namespace App\Http\Controllers\Api;

use App\Http\Controllers\Controller;
use App\Http\Resources\OrderResource;
use App\Models\Notification;
use App\Models\Order;
use App\Models\OrderService;
use App\Models\Service;
use App\Models\UserToken;
use App\User;
use Edujugon\PushNotification\PushNotification;
use Illuminate\Http\Request;
use JWTAuth;

class OrdersController extends Controller
{
    public function accept_order($id)
    {
        $lang = \request()->header('Accept-Language', 'ar');
        \App::setLocale($lang);
        if (!$user = JWTAuth::parseToken()->authenticate()) {
            return response()->json(['value' => false, 'msg' => \Lang::get('wrong token'), 'code' => 401]);
        }

        $order = Order::find($id);
        if (!$order) return response()->json(['value' => false, 'msg' => 'wrong id', 'code' => 422]);

        if ($order->barber_id) return response()->json(['value' => false, 'msg' => \Lang::get('data.another_barber'), 'code' => 422]);

        $user_orders = Order::where('barber_id',$user->id)->where('status','!=','finish')->where('status','!=','canceled')->count();
        if ($user_orders > 0) return response()->json(['value'=>false,'msg'=>\Lang::get('data.orders_exists'),'code'=>200]);

        $order->barber_id = $user->id;
        $order->status = 'barber_accept';
        $order->update();
        // notify the client
        $client = User::find($order->user_id);
        $tokens = UserToken::where('user_id', $client->id)->whereStatus('connected')->get();
        $barber_name = $order->barber->name . " " . $order->barber->last_name;

        $notification = new Notification();
        $notification['user_id'] = $client->id;
        $notification['body->ar'] = "تمت الموافقه علي طلبكم من قبل الحلاق  $barber_name ";
        $notification['body->en'] = "Your order is accepted by $barber_name";
        $notification['order_id'] = $order->id;
        $notification['type'] = 'barber_accept';

        $notification['seen'] = 'false';
        $notification->save();
        foreach ($tokens as $token) {


            if ($token->lang == 'ar'){
                $title = 'تمت الموافقه علي طلبكم';
                $body = "تمت الموافقه علي طلبكم من قبل الحلاق  $barber_name ";
            }else{

                $title = 'Your order is accepted';
                $body = "Your order is accepted by $barber_name";

            }

            $push = new PushNotification('fcm');

            $barber_rate = getRateForUser($user->id);
            if ($token->device_type == 'ios') {

                $msg = [
                    'data' => [
                        'title_ar' => "تمت الموافقه علي طلبكم",
                        'title_en' => "Your order is accepted",
                        'body_ar' => "تمت الموافقه علي طلبكم من قبل الحلاق  $barber_name ",
                        'body_en' => "Your order is accepted by $barber_name",
                        'type' => 'barber_accept',
                        'title'=>$title,
                        'body'=>$body,
                        'barber_id' => $user->id,
                        'barber_name' => $user->name,
                        'barber_mobile' => $user->mobile,
                        'barber_rate' => $barber_rate,
                        'barber_lat' => $user->lat,
                        'barber_lng' => $user->lng,
                        'order_lat' => $order->address->lat,
                        'order_lng' => $order->address->lng,
                        'address' => $order->address->address,
                        'order_id' => $order->id,

                        'sound' => 'default',
                        'click_action' => 'FCM_PLUGIN_ACTIVITY',
                    ],
                    'notification' => [
                        'title_ar' => "تمت الموافقه علي طلبكم",
                        'title_en' => "Your order is accepted",
                        'body_ar' => "تمت الموافقه علي طلبكم من قبل الحلاق  $barber_name ",
                        'body_en' => "Your order is accepted by $barber_name",
                        'type' => 'barber_accept',
                        'barber_id' => $user->id,
                        'barber_name' => $user->name,
                        'barber_mobile' => $user->mobile,
                        'barber_rate' => $barber_rate,
                        'barber_lat' => $user->lat,
                        'barber_lng' => $user->lng,
                        'order_lat' => $order->address->lat,
                        'order_lng' => $order->address->lng,
                        'address' => $order->address->address,
                        'title'=>$title,
                        'body'=>$body,
                        'order_id' => $order->id,

                        'sound' => 'default',
                        'click_action' => 'FCM_PLUGIN_ACTIVITY',
                    ],
                    'priority' => 'high',
                ];
                $push->setMessage($msg)
                    ->setDevicesToken($token->token)
                    ->send();

            } else {
                $msg = [
                    'data' => [
                        'title_ar' => "تمت الموافقه علي طلبكم",
                        'title_en' => "Your order is accepted",
                        'body_ar' => "تمت الموافقه علي طلبكم من قبل الحلاق  $barber_name ",
                        'body_en' => "Your order is accepted by $barber_name",
                        'type' => 'barber_accept',
                        'barber_id' => $user->id,
                        'barber_name' => $user->name,
                        'barber_mobile' => $user->mobile,
                        'barber_rate' => $barber_rate,
                        'barber_lat' => $user->lat,
                        'barber_lng' => $user->lng,
                        'order_lat' => $order->address->lat,
                        'order_lng' => $order->address->lng,
                        'address' => $order->address->address,
                        'title'=>$title,
                        'body'=>$body,
                        'order_id' => $order->id,

                        'sound' => 'default',
                        'click_action' => 'FCM_PLUGIN_ACTIVITY',
                    ],
                    'priority' => 'high',
                ];
                $push->setMessage($msg)
                    ->setDevicesToken($token->token)
                    ->send();

            }


        }

        $data = new OrderResource($order);
        return response()->json(['value' => true, 'data' => $data, 'code' => 200]);

    }

    public function barber_on_way($id)
    {
        $lang = \request()->header('Accept-Language', 'ar');
        \App::setLocale($lang);
        if (!$user = JWTAuth::parseToken()->authenticate()) {
            return response()->json(['value' => false, 'msg' => \Lang::get('wrong token'), 'code' => 401]);
        }

        $order = Order::find($id);
        if (!$order) return response()->json(['value' => false, 'msg' => 'wrong id', 'code' => 422]);


        $order->status = 'barber_in_way';
        $order->update();

        // notify the client
        $client = User::find($order->user_id);
        $notification = new Notification();
        $notification['user_id'] = $client->id;
        $notification['body->ar'] = "الحلاق في الطريق إليكم";
        $notification['body->en'] = "The barber is on his way to you";
        $notification['order_id'] = $order->id;
        $notification['type'] = 'barber_in_way';

        $notification['seen'] = 'false';
        $notification->save();
        $tokens = UserToken::where('user_id', $client->id)->whereStatus('connected')->get();
        foreach ($tokens as $token) {

            $push = new PushNotification('fcm');

            $barber_name = $order->barber->name . " " . $order->barber->last_name;




            if ($token->lang == 'ar'){
                $title = 'الحلاق في الطريق إليكم';
                $body = "الحلاق في الطريق إليكم";
            }else{

                $title = 'The barber is on his way to you';
                $body = "The barber is on his way to you";

            }




            if ($token->device_type == 'ios') {
                $msg = [
                    'data' => [
                        'title_ar' => "الحلاق في الطريق إليكم",
                        'title_en' => "The barber is on his way to you",
                        'body_ar' => "الحلاق في الطريق إليكم",
                        'body_en' => "The barber is on his way to you",
                        'type' => 'barber_in_way',
                        'barber_id' => $user->id,
                        'title' => $title,
                        'body' => $body,
                        'order_id' => $order->id,

                        'sound' => 'default',
                        'click_action' => 'FCM_PLUGIN_ACTIVITY',
                    ],
                    'notification' => [
                        'title_ar' => "الحلاق في الطريق إليكم",
                        'title_en' => "The barber is on his way to you",
                        'body_ar' => "الحلاق في الطريق إليكم",
                        'body_en' => "The barber is on his way to you",
                        'type' => 'barber_in_way',
                        'barber_id' => $user->id,
                        'title' => $title,
                        'body' => $body,
                        'order_id' => $order->id,

                        'sound' => 'default',
                        'click_action' => 'FCM_PLUGIN_ACTIVITY',
                    ],
                    'priority' => 'high',
                ];
                $push->setMessage($msg)
                    ->setDevicesToken($token->token)
                    ->send();

            } else {
                $msg = [
                    'data' => [
                        'title_ar' => "الحلاق في الطريق إليكم",
                        'title_en' => "The barber is on his way to you",
                        'body_ar' => "الحلاق في الطريق إليكم",
                        'body_en' => "The barber is on his way to you",
                        'type' => 'barber_in_way',
                        'barber_id' => $user->id,
                        'title' => $title,
                        'body' => $body,
                        'order_id' => $order->id,

                        'sound' => 'default',
                        'click_action' => 'FCM_PLUGIN_ACTIVITY',
                    ],
                    'priority' => 'high',
                ];
                $push->setMessage($msg)
                    ->setDevicesToken($token->token)
                    ->send();

            }


        }


        $data = new OrderResource($order);
        return response()->json(['value' => true, 'data' => $data, 'code' => 200]);

    }

    public function finish_order(Request $request)
    {
        $lang = \request()->header('Accept-Language', 'ar');
        \App::setLocale($lang);
        if (!$user = JWTAuth::parseToken()->authenticate()) {
            return response()->json(['value' => false, 'msg' => \Lang::get('wrong token'), 'code' => 401]);
        }
        $validator = \Validator::make($request->all(), [
            'order_id' => 'required|exists:orders,id',
            'paid_amount' => 'required'
        ]);

        if (count($validator->errors()) > 0) return response()->json(['value' => false, 'msg' => $validator->errors()->first(), 'code' => 422]);
        $order = Order::find($request['order_id']);
        $order->status = 'finish';
        $order->paid_amount = $request['paid_amount'];
        $order->update();


        // notify the client
        $client = User::find($order->user_id);

        $notification = new Notification();
        $notification['user_id'] = $client->id;
        $notification['body->ar'] = "تمت الإنتهاء من الطلب";
        $notification['body->en'] = "The Order is finished";
        $notification['order_id'] = $order->id;
        $notification['type'] = 'finish';

        $notification['seen'] = 'false';
        $notification->save();
        $tokens = UserToken::where('user_id', $client->id)->whereStatus('connected')->get();
        foreach ($tokens as $token) {
            if ($token->lang == 'ar'){
                $title = 'تمت الإنتهاء من الطلب';
                $body = "تمت الإنتهاء من الطلب";
            }else{

                $title = 'The Order is finished';
                $body = "The Order is finished";

            }

            $push = new PushNotification('fcm');

            $barber_name = $order->barber->name . " " . $order->barber->last_name;

            if ($token->device_type == 'ios') {
                $msg = [
                    'data' => [
                        'title_ar' => "تمت الإنتهاء من الطلب",
                        'title_en' => "The Order is finished",
                        'body_ar' => "تمت الإنتهاء من الطلب",
                        'body_en' => "The Order is finished",
                        'type' => 'finish',
                        'barber_id' => $user->id,
                        'barber_name'=>$barber_name,
                        'sound' => 'default',
                        'title' => $title,
                        'body' => $body,
                        'order_id' => $order->id,

                        'click_action' => 'FCM_PLUGIN_ACTIVITY',
                    ],
                    'notification' => [
                        'title_ar' => "تمت الإنتهاء من الطلب",
                        'title_en' => "The Order is finished",
                        'body_ar' => "تمت الإنتهاء من الطلب",
                        'body_en' => "The Order is finished",
                        'type' => 'finish',
                        'barber_id' => $user->id,
                        'barber_name'=>$barber_name,
                        'title' => $title,
                        'body' => $body,
                        'order_id' => $order->id,

                        'sound' => 'default',
                        'click_action' => 'FCM_PLUGIN_ACTIVITY',
                    ],
                    'priority' => 'high',
                ];
                $push->setMessage($msg)
                    ->setDevicesToken($token->token)
                    ->send();

            } else {
                $msg = [
                    'data' => [
                        'title_ar' => "تمت الإنتهاء من الطلب",
                        'title_en' => "The Order is finished",
                        'body_ar' => "تمت الإنتهاء من الطلب",
                        'body_en' => "The Order is finished",
                        'type' => 'finish',
                        'barber_id' => $user->id,
                        'barber_name'=>$barber_name,
                        'title' => $title,
                        'body' => $body,
                        'sound' => 'default',
                        'order_id' => $order->id,

                        'click_action' => 'FCM_PLUGIN_ACTIVITY',
                    ],
                    'priority' => 'high',
                ];
                $push->setMessage($msg)
                    ->setDevicesToken($token->token)
                    ->send();

            }


        }


        $data = new OrderResource($order);
        return response()->json(['value' => true, 'data' => $data, 'code' => 200]);

    }

    public function start_order($id)
    {
        $lang = \request()->header('Accept-Language', 'ar');
        \App::setLocale($lang);
        if (!$user = JWTAuth::parseToken()->authenticate()) {
            return response()->json(['value' => false, 'msg' => \Lang::get('wrong token'), 'code' => 401]);
        }

        $order = Order::find($id);
        if (!$order) return response()->json(['value' => false, 'msg' => 'wrong id', 'code' => 422]);


        $order->status = 'ongoing';
        $order->update();


        // notify the client
        $client = User::find($order->user_id);

        $notification = new Notification();
        $notification['user_id'] = $client->id;
        $notification['body->ar'] = "تم البدأ في الطلب";
        $notification['body->en'] = "The Order is started";
        $notification['order_id'] = $order->id;
        $notification['type'] = 'ongoing';

        $notification['seen'] = 'false';
        $notification->save();
        $tokens = UserToken::where('user_id', $client->id)->whereStatus('connected')->get();
        foreach ($tokens as $token) {

            $push = new PushNotification('fcm');

            $barber_name = $order->barber->name . " " . $order->barber->last_name;
            if ($token->lang == 'ar'){
                $title = 'تم البدأ في الطلب';
                $body = "تم البدأ في الطلب";
            }else{

                $title = 'The Order is started';
                $body = "The Order is started";

            }
            if ($token->device_type == 'ios') {
                $msg = [
                    'data' => [
                        'title_ar' => "تم البدأ في الطلب",
                        'title_en' => "The Order is started",
                        'body_ar' => "تم البدأ في الطلب",
                        'body_en' => "The Order is started",
                        'type' => 'ongoing',
                        'sound' => 'default',
                        'barber_id' => $user->id,
                        'barber_name'=>$barber_name,
                        'title' => $title,
                        'body' => $body,
                        'order_id' => $order->id,

                        'click_action' => 'FCM_PLUGIN_ACTIVITY',
                    ],
                    'notification' => [
                        'title_ar' => "تم البدأ في الطلب",
                        'title_en' => "The Order is started",
                        'body_ar' => "تم البدأ في الطلب",
                        'body_en' => "The Order is started",
                        'type' => 'ongoing',
                        'sound' => 'default',
                        'barber_id' => $user->id,
                        'barber_name'=>$barber_name,
                        'title' => $title,
                        'body' => $body,
                        'order_id' => $order->id,

                        'click_action' => 'FCM_PLUGIN_ACTIVITY',
                    ],
                    'priority' => 'high',
                ];
                $push->setMessage($msg)
                    ->setDevicesToken($token->token)
                    ->send();

            } else {
                $msg = [
                    'data' => [
                        'title_ar' => "تم البدأ في الطلب",
                        'title_en' => "The Order is started",
                        'body_ar' => "تم البدأ في الطلب",
                        'body_en' => "The Order is started",
                        'type' => 'ongoing',
                        'sound' => 'default',
                        'barber_id' => $user->id,
                        'barber_name'=>$barber_name,
                        'title' => $title,
                        'body' => $body,
                        'order_id' => $order->id,

                        'click_action' => 'FCM_PLUGIN_ACTIVITY',
                    ],
                    'priority' => 'high',
                ];
                $push->setMessage($msg)
                    ->setDevicesToken($token->token)
                    ->send();

            }


        }


        $data = new OrderResource($order);
        return response()->json(['value' => true, 'data' => $data, 'code' => 200]);

    }

    public function additional_services(Request $request)
    {
        $lang = \request()->header('Accept-Language', 'ar');
        \App::setLocale($lang);
        if (!$user = JWTAuth::parseToken()->authenticate()) {
            return response()->json(['value' => false, 'msg' => \Lang::get('wrong token'), 'code' => 401]);
        }
        $validator = \Validator::make($request->all(), [
            'services_id' => 'required',
            'services_counts' => 'required',
            'order_id' => 'required|exists:orders,id'
        ]);
        if ($validator->passes()) {

            $service_ids = explode(',', $request['services_id']);
            $service_counts = explode(',', $request['services_counts']);
            $counter = 0;
            $order = Order::find($request['order_id']);
            $price = 0;
            foreach ($service_ids as $item) {

                OrderService::create([
                    'order_id' => $order->id,
                    'service_id' => $service_ids[$counter],
                    'count' => $service_counts[$counter],
                    'barber_added' => 'true'
                ]);
                $service = Service::find($service_ids[$counter]);
                $price += $service->price + $service_counts[$counter];


                $counter++;
            }


            // notification for user
            $owner = User::find($order->user_id);

            $push = new PushNotification('fcm');
            $notification = new Notification();
            $notification['user_id'] = $owner->id;
            $notification['body->ar'] = 'قام الحلاق بإضافة خدمات اضافة';
            $notification['body->en'] = 'The barber added a new additional services';
            $notification['order_id'] = $order->id;
            $notification['type'] = 'additional_service';
            $notification['seen'] = 'false';
            $notification->save();

            $tokens = UserToken::where('user_id', $owner->id)->whereStatus('connected')->get();

            foreach ($tokens as $token) {

                if ($token->lang == 'ar'){
                    $title = 'قام الحلاق بإضافة خدمات اضافة';
                    $body = "قام الحلاق بإضافة خدمات اضافة";
                }else{

                    $title = 'The barber added additional services';
                    $body = "The barber added additional services";

                }


                if ($token->device_type == 'ios') {
                    $msg = [
                        'data' => [
                            'title_ar' => "قام الحلاق بإضافة خدمات اضافة",
                            'title_en' => "The barber added additional services",
                            'body_ar' => "قام الحلاق بإضافة خدمات اضافة",
                            'body_en' => "The barber added additional services",
                            'type' => 'additional_service',
                            'sound' => 'default',
                            'barber_id' => $user->id,
                            'additional_price' => $price,
                            'title' => $title,
                            'body' => $body,
                            'order_id' => $order->id,

                            'click_action' => 'FCM_PLUGIN_ACTIVITY',
                        ],
                        'notification' => [
                            'title_ar' => "قام الحلاق بإضافة خدمات اضافة",
                            'title_en' => "The barber added additional services",
                            'body_ar' => "قام الحلاق بإضافة خدمات اضافة",
                            'body_en' => "The barber added additional services",
                            'type' => 'additional_service',
                            'barber_id' => $user->id,
                            'additional_price' => $price,
                            'title' => $title,
                            'body' => $body,
                            'order_id' => $order->id,

                            'sound' => 'default',
                            'click_action' => 'FCM_PLUGIN_ACTIVITY',
                        ],
                        'priority' => 'high',
                    ];
                    $push->setMessage($msg)
                        ->setDevicesToken($token->token)
                        ->send();

                } else {
                    $msg = [
                        'data' => [
                            'title_ar' => "قام الحلاق بإضافة خدمات اضافة",
                            'title_en' => "The barber added additional services",
                            'body_ar' => "قام الحلاق بإضافة خدمات اضافة",
                            'body_en' => "The barber added additional services",
                            'type' => 'additional_service',
                            'barber_id' => $user->id,
                            'additional_price' => $price,
                            'title' => $title,
                            'body' => $body,
                            'order_id' => $order->id,

                            'sound' => 'default',
                            'click_action' => 'FCM_PLUGIN_ACTIVITY',
                        ],
                        'priority' => 'high',
                    ];
                    $push->setMessage($msg)
                        ->setDevicesToken($token->token)
                        ->send();

                }


            }
            $data = new OrderResource($order);
            return response()->json(['value' => true, 'data' => $data, 'code' => 200]);


        } else {
            return response()->json(['value' => false, 'msg' => $validator->errors()->first(), 'code' => 422]);
        }

    }

    public function added_additional_services($id)
    {
        $lang = \request()->header('Accept-Language', 'ar');
        \App::setLocale($lang);
        if (!$user = JWTAuth::parseToken()->authenticate()) {
            return response()->json(['value' => false, 'msg' => \Lang::get('wrong token'), 'code' => 401]);
        }
        $order = Order::find($id);
        $rows = OrderService::where('order_id', $order->id)->where('barber_added', 'true')->get();
        $data = [];
        foreach ($rows as $row) {
            $service = Service::find($row->service_id);
            $arr['service_id'] = $row->service_id;
            $arr['service_name'] = $service->name[$lang];
            $arr['service_price'] = $service->price;
            $arr['count'] = $row->count;
            $arr['price'] = $service->price * $row->count;
            $data[] = $arr;

        }
        return response()->json(['value' => true, 'data' => $data, 'code' => 200]);
    }

    public function accept_additional_services($id)
    {
        $lang = \request()->header('Accept-Language', 'ar');
        \App::setLocale($lang);
        if (!$user = JWTAuth::parseToken()->authenticate()) {
            return response()->json(['value' => false, 'msg' => \Lang::get('wrong token'), 'code' => 401]);
        }
        $order = Order::find($id);

        OrderService::where('order_id', $order->id)->where('barber_added', 'true')->update([
            'barber_added' => null
        ]);
        $additional_price = 0;
        $rows = OrderService::where('order_id', $order->id)->get();
        foreach ($rows as $row) {
            $service = Service::find($row->service_id);
            $additional_price += $service->price * $row->count;
        }
        $order->services_price = $additional_price;
        $additional_price_fee = $additional_price + 15;
        if ($additional_price_fee > 100) {
            $order->total_price = $additional_price_fee - ($additional_price_fee * 10 / 100);
            $order->update();
        }
        $order->update();


        // notification for barber
        $barber = User::find($order->barber_id);
        $notification = new Notification();
        $notification['user_id'] = $barber->id;
        $notification['body->ar'] = 'تمت الموافقه من قبل العميل علي اضافه الخدمات';
        $notification['body->en'] = 'The client accepted the additional services';
        $notification['order_id'] = $order->id;
        $notification['type'] = 'accept_additional';
        $notification['seen'] = 'false';
        $notification->save();

        $tokens = UserToken::where('user_id', $barber->id)->whereStatus('connected')->get();

        foreach ($tokens as $token) {


            if ($token->lang == 'ar'){
                $title = 'تمت الموافقه من قبل العميل علي اضافه الخدمات';
                $body = "تمت الموافقه من قبل العميل علي اضافه الخدمات";
            }else{

                $title = 'The client accepted the additional services';
                $body = "The client accepted the additional services";

            }


            $push = new PushNotification('fcm');

            if ($token->device_type == 'ios') {
                $msg = [
                    'data' => [
                        'title_ar' => "تمت الموافقه من قبل العميل علي اضافه الخدمات",
                        'title_en' => "The client accepted the additional services",
                        'body_ar' => "تمت الموافقه من قبل العميل علي اضافه الخدمات",
                        'body_en' => "The client accepted the additional services",
                        'type' => 'accept_additional',
                        'barber_id' => $barber->id,
                        'title' => $title,
                        'body' => $body,
                        'order_id' => $order->id,

                        'sound' => 'default',
                        'click_action' => 'FCM_PLUGIN_ACTIVITY',
                    ],
                    'notification' => [
                        'title_ar' => "تمت الموافقه من قبل العميل علي اضافه الخدمات",
                        'title_en' => "The client accepted the additional services",
                        'body_ar' => "تمت الموافقه من قبل العميل علي اضافه الخدمات",
                        'body_en' => "The client accepted the additional services",
                        'type' => 'accept_additional',
                        'barber_id' => $barber->id,
                        'title' => $title,
                        'body' => $body,
                        'order_id' => $order->id,

                        'sound' => 'default',
                        'click_action' => 'FCM_PLUGIN_ACTIVITY',
                    ],
                    'priority' => 'high',
                ];
                $push->setMessage($msg)
                    ->setDevicesToken($token->token)
                    ->send();

            } else {
                $msg = [
                    'data' => [
                        'title_ar' => "تمت الموافقه من قبل العميل علي اضافه الخدمات",
                        'title_en' => "The client accepted the additional services",
                        'body_ar' => "تمت الموافقه من قبل العميل علي اضافه الخدمات",
                        'body_en' => "The client accepted the additional services",
                        'type' => 'accept_additional',
                        'barber_id' => $barber->id,
                        'title' => $title,
                        'body' => $body,
                        'order_id' => $order->id,

                        'sound' => 'default',
                        'click_action' => 'FCM_PLUGIN_ACTIVITY',
                    ],
                    'priority' => 'high',
                ];
                $push->setMessage($msg)
                    ->setDevicesToken($token->token)
                    ->send();

            }


        }


        $data = new OrderResource($order);
        return response()->json(['value' => true, 'data' => $data, 'code' => 200]);


    }
    public function refuse_additional_services($id)
    {
        $lang = \request()->header('Accept-Language', 'ar');
        \App::setLocale($lang);
        if (!$user = JWTAuth::parseToken()->authenticate()) {
            return response()->json(['value' => false, 'msg' => \Lang::get('wrong token'), 'code' => 401]);
        }
        $order = Order::find($id);

        OrderService::where('order_id', $order->id)->where('barber_added', 'true')->delete();

        // notification for barber
        $barber = User::find($order->barber_id);
        $notification = new Notification();
        $notification['user_id'] = $barber->id;
        $notification['body->ar'] = 'تم الرفض من قبل العميل علي اضافه الخدمات';
        $notification['body->en'] = 'The client refused the additional services';
        $notification['order_id'] = $order->id;
        $notification['type'] = 'refuse_additional';
        $notification['seen'] = 'false';
        $notification->save();

        $tokens = UserToken::where('user_id', $barber->id)->whereStatus('connected')->get();

        foreach ($tokens as $token) {

            if ($token->lang == 'ar'){
                $title = 'تم الرفض من قبل العميل علي اضافه الخدمات';
                $body = "تم الرفض من قبل العميل علي اضافه الخدمات";
            }else{

                $title = 'The client refused the additional services';
                $body = "The client refused the additional services";

            }
            $push = new PushNotification('fcm');

            if ($token->device_type == 'ios')
            {
                $msg = [
                    'data' => [
                        'title_ar' => "تم الرفض من قبل العميل علي اضافه الخدمات",
                        'title_en' => "The client refused the additional services",
                        'body_ar' => "تم الرفض من قبل العميل علي اضافه الخدمات",
                        'body_en' => "The client refused the additional services",
                        'type' => 'refuse_additional',
                        'barber_id' => $barber->id,
                        'title' => $title,
                        'body' => $body,
                        'order_id' => $order->id,

                        'sound' => 'default',
                        'click_action' => 'FCM_PLUGIN_ACTIVITY',
                    ],
                    'notification' => [
                        'title_ar' => "تم الرفض من قبل العميل علي اضافه الخدمات",
                        'title_en' => "The client refused the additional services",
                        'body_ar' => "تم الرفض من قبل العميل علي اضافه الخدمات",
                        'body_en' => "The client refused the additional services",
                        'type' => 'refuse_additional',
                        'barber_id' => $barber->id,
                        'title' => $title,
                        'order_id' => $order->id,

                        'body' => $body,
                        'sound' => 'default',
                        'click_action' => 'FCM_PLUGIN_ACTIVITY',
                    ],
                    'priority' => 'high',
                ];
                $push->setMessage($msg)
                    ->setDevicesToken($token->token)
                    ->send();

            } else {
                $msg = [
                    'data' => [
                        'title_ar' => "تم الرفض من قبل العميل علي اضافه الخدمات",
                        'title_en' => "The client refused the additional services",
                        'body_ar' => "تمت الموافقه من قبل العميل علي اضافه الخدمات",
                        'body_en' => "The client accepted the additional services",
                        'type' => 'refuse_additional',
                        'barber_id' => $barber->id,
                        'title' => $title,
                        'body' => $body,
                        'order_id' => $order->id,

                        'sound' => 'default',
                        'click_action' => 'FCM_PLUGIN_ACTIVITY',
                    ],
                    'priority' => 'high',
                ];
                $push->setMessage($msg)
                    ->setDevicesToken($token->token)
                    ->send();

            }


        }


        $data = new OrderResource($order);
        return response()->json(['value' => true, 'data' => $data, 'code' => 200]);


    }
}
